import { NavLink, useLocation } from "react-router-dom";
import { useNavItem } from "./useNavItem";
import { twMerge } from "tailwind-merge";
import React from "react";

interface NavItem {
	to: string;
	label: string;
	icon?: React.ReactNode;
}

interface NavigationProps {
	className?: string;
}

export default function Navigation({ className }: NavigationProps) {
	const { navItems } = useNavItem();
	const location = useLocation();

	const isActive = (to: string) => {
		const [pathname, search] = to.split("?");
		return (
			location.pathname === pathname &&
			(!search ? !location.search : location.search === `?${search}`)
		);
	};

	return (
		<nav className={twMerge("mt-4 w-full", className)}>
			<div className="flex justify-between">
				<div className="flex w-full space-x-4 overflow-x-auto scrollbar-none">
					{navItems.map((item) => (
						<NavLink
							key={item.to}
							to={item.to}
							className={({ isActive: active }) =>
								twMerge(
									"border-4 border-white flex-1 px-4 py-4 text-lg font-bold rounded-xl",
									"transition-all duration-300 ease-out", // 增加过渡时间让效果更平滑
									"bg-gradient-to-r from-white to-blue-100", // 白色到淡蓝色渐变
									"text-blue-800", // 深蓝色文字
									"hover:from-blue-800 hover:to-blue-700 hover:text-white", // 悬停时背景变深蓝色，文字变白色
									active &&
										"from-blue-800 to-blue-700 text-white" // 激活状态样式
								)
							}>
							<span className="flex items-center justify-center gap-4">
								{item.icon &&
									React.cloneElement(
										item.icon as React.ReactElement,
										{
											style: { fontSize: "28px" },
											className: " ", // 给图标添加颜色过渡效果
										}
									)}
								<span className="tracking-wide">
									{item.label}
								</span>
							</span>
						</NavLink>
					))}
				</div>
			</div>
		</nav>
	);
}
